package graphe;
use utf8;

sub CTTcand2gml {

#-------------------------
# definitions de variables
#-------------------------
my $file=shift(@_);
my %listeMot={};
my %listePatron={};
my $sortie="patrons.gml";

#-------------------------
# Partie 1
# A. ouverture du fichier des patrons : ce fichier contient sur chaque ligne une sequence : mot1 mot2
# B. dans la boucle while qui suit on va reperer pour chaque mot (a gauche du patron) 
# l'ensemble des mots associés (a droite du precedent)
# on cree ensuite un tableau indexe qui associe au mot de gauche la liste des mots associes
# motgauche -> (motdroite-1,motdroite-2,...)
# on n'ajoute qu'une seule occurrence des mots presents a droite mais on compte 
# la frequence d'un patron donne dans un tableau de patron 
#-------------------------

##on s'est assuré que les fichiers de candidats issus d'un traitement avec TreeTagger ou Cordial étaient bien codés en utf8. Ceci nous permet d'assurer un bon fonctionnement de l'expression régulière codée dans le programme : le fichier du programme est en utf8 et on utilise 'use utf8'.
##On a donc un fonctionnement stable du module

open(F,"<:encoding(utf8)",$file) or die "pb avec le fichier en ouverture";
while (<F>) {
my $ligne=$_;

    $ligne=~/([\wÆÁÂÀÅÃÄÇÇÇÐÉÊÈËÍÎÌÌÏÑÓÔÒØÕÖÞÚÛÙÜÝáâæàåãäçéêèðëíîìïñóôòøõößþúûùüýÿ]+)[^\wÆÁÂÀÅÃÄÇÇÇÐÉÊÈËÍÎÌÌÏÑÓÔÒØÕÖÞÚÛÙÜÝáâæàåãäçéêèðëíîìïñóôòøõößþúûùüýÿ]+([\wÆÁÂÀÅÃÄÇÇÇÐÉÊÈËÍÎÌÌÏÑÓÔÒØÕÖÞÚÛÙÜÝáâæàåãäçéêèðëíîìïñóôòøõößþúûùüýÿ]+)/;
    my $mot1=$1;
    my $mot2=$2;
    my $patron="$mot1\t$mot2";
    if (!(exists($listeMot{$mot1}))) {
	my @tmp=();
	push(@tmp,$mot2);
	$listeMot{$mot1}=\@tmp;
	$listePatron{$patron}++;
    }
    else {
	my $tmp=$listeMot{$mot1};
	my @tmp2=@$tmp;
	if (!(grep(/$mot2/, @tmp2))) {
	    push(@tmp2,$mot2);
	}
	$listeMot{$mot1}=\@tmp2;
	$listePatron{$patron}++;
    }
}
close(F);
#-------------------------
# Partie 2
# A. Creation du fichier de sortie et squelette minimal
# B. parcours du tableau des associations motgauche -> (motdroite-1,motdroite-2,...)
# pour chaque motgauche on cree un noeud du graphe idem pour chaque mot de la liste associee
# afin de ne pas creer de doublon on utilise un tableau contenant pour chaque mot son indice
# on verifie dans ce tableau la presence ou non du mot a associer a un noeud
#-------------------------

open (F,">:encoding(utf8)","$sortie");
print F "<?xml version=\"1.0\" encoding=\"utf-8\"?>\n";
print F "<graphml>\n";
print F " <key id=\"d0\" for=\"node\" attr.name=\"forme\" attr.type=\"string\"/>\n";
print F " <key id=\"d1\" for=\"edge\" attr.name=\"frequence\" attr.type=\"double\"/>\n";
print F "  <graph edgedefault=\"undirected\">\n";

my $id=1;
my $listeId={};

while (($mot, $liste) = each(%listeMot)) {
    my @tmp=@$liste;
    if ($mot !~/HASH/) {
	my $tmpID;
	if (!(exists($listeId{$mot}))) {
	    print F "  <node id=\"$id\"><data key=\"d0\">$mot</data></node>\n";
	    $listeId{$mot}=$id;
	    $tmpID=$id;
	    $id++;
	}
	else {
	    $tmpID=$listeId{$mot};
	}
	foreach my $cible (@tmp) {
	    my $nbpatron=0;
	    $patron="$mot\t$cible";
	    $nbpatron=$listePatron{$patron};
	    if (!(exists($listeId{$cible}))) {
		print F "  <node id=\"$id\"><data key=\"d0\">$cible</data></node>\n";
		$listeId{$cible}=$id;
		print F "  <edge source=\"$tmpID\" target=\"$id\"><data key=\"d1\">$nbpatron</data></edge>\n";
		$id++;
	    }
	    else {
		print F "  <edge source=\"$tmpID\" target=\"$listeId{$cible}\"><data key=\"d1\">$nbpatron</data></edge>\n";
	    }
	}
    }
    
} 


print F " </graph>\n";
print F "</graphml>\n";


close(F);
return ('patrons.gml');
}
1;
#Cette fonction appelle le moteur xsltproc, qui applique une feuille de transformation xslt au fichier gml créé dans la fonction précédente.
sub CTTgml2pajek
{
	$xml=shift(@_);
	system("xsltproc -o pajek.txt GraphML2Pajek.xsl $xml");
	return ('pajek.txt');
}


1;
